tw2.ace
=======

tw2.ace is a widget library for the ToscaWidgets 2 framework,
which provides a JavaScript-based source code editor using the
`ACE`_ JavaScript application.

.. _ACE: http://ace.ajax.org/

This library is merely a convenience for using ACE through tw2,
all major credit goes to the developers of ACE.
See also their repository at https://github.com/ajaxorg/ace

This package comes bundled with ACE from 11.05.2012, which is released
under a BSD-3-Clause license.
This package itself is licensed under the WTFPL, Version 2 (for the moment).

The directory ``ace-builds`` is a git submodule, but you don't have to
check it out if you want to use tw2.ace! It is only included as a convenience
for updating the bundled libraries.
